#!/usr/bin/env python

from __future__ import print_function

import argparse
import os

from os.path import expanduser, join

from .page import Page

def main():
    parser = argparse.ArgumentParser(
            description='Min pages',
            )
    
    parser.add_argument('page', nargs='?', help='Which page to view/edit/delete' )
    parser.add_argument('-e','--edit', help='Edit/create a page', action='store_true')
    parser.add_argument('-d','--delete', help='Delete a page', action='store_true')
    def_page_dir =  join(expanduser('~'),'.minpages')
    parser.add_argument(
            '--page-dir', 
            help='The pages directory (default: {default})'.format(
                default=def_page_dir
                ), 
            default=def_page_dir
            )
    try:
        def_editor = os.environ['VISUAL']
    except KeyError:
        def_editor = 'vi'
    parser.add_argument(
            '--editor', 
            help='The editor to use (default: {default})'.format(
                default=def_editor
                ), 
            default=def_editor
            )

    args = vars(parser.parse_args())

    Page(args)

if __name__ == '__main__':
    main()



#!/usr/bin/env python

from __future__ import print_function

import sys
import os
import ntpath
import subprocess
from click import confirm
from shutil import copytree

from os.path import join, exists, expanduser

class Page():
    def __init__(self, args):
        self.page_dir = args['page_dir']
        self.editor = args['editor']

        if not exists(self.page_dir):
            import minpages
            data_dir = join(minpages.__path__[0],'pages')
            if confirm(
"""Page directory not yet created at '{page_dir}'.
Would you like to create it from {data_dir}?""".format(
                    page_dir=self.page_dir,
                    data_dir=data_dir
            )):
                copytree(data_dir,self.page_dir)
            else:
                sys.exit("No page directory, halted")


        if args['page'] is None:
            self.show_all_pages()
        elif args['edit']:
            self.edit_page(args['page'])
        elif args['delete']:
            self.delete_page(args['page'])
        else:
            self.show_page(args['page'])
       
    def show_all_pages(self):
        files = os.listdir(self.page_dir)
        print('Pages: ')
        print('-'*50)
        for file_name in files:
            if not(file_name[0] == '.'):
                print(ntpath.basename(file_name))
        print('-'*50)
    def show_page(self, page):
        file_name = join(self.page_dir, page)
        if exists(file_name):
            print(page+':')
            print('-'*50)
            with open(file_name,'r') as fout:
                print(fout.read())
            print('-'*50)
        else:
            print("Page '"+page+"' does not exist")
            if confirm("Would you like to create it?"):
                self.edit_page(page)
    def edit_page(self, page):
        file_name = join(self.page_dir, page)
        try:
            subprocess.call([self.editor, file_name])
        except OSError:
            print("Editor: '"+self.editor+"' does not exist",\
                    file=sys.stderr)
        self.show_page(page)
    def delete_page(self, page):
        file_name = join(self.page_dir, page)
        if exists(file_name):
            if confirm(\
                    "Are you sure you want to delete the page '"\
                    + page + "'?" ):
                os.remove(file_name)
                print("Removed page")
            else:
                print("Did not remove page")
        else:
            print("Page '"+page+"' does not exist")





#!/usr/bin/env python
from __future__ import print_function

from glob import glob
from setuptools import setup, find_packages

setup(
        name = 'minpages',
        version = '0.0.12',
        description = 'An abbreviated man-pages', 
        long_description = """
A simple way to make a man page or add a reminder""",
        url = 'http://github.com/brian-bk/minpages/',
        license='GPL',
        author = 'Brian Kleszyk',
        author_email = 'bkleszyk@gmail.com',
        packages = find_packages(),
        package_dir={'minpages':'minpages'},
        package_data={'minpages':['pages/*']},
        entry_points = {
            'console_scripts': [
                'min = minpages.min:main'
            ]
        },
        install_requires=['click']
)


